abacusai.refresh_pipeline_run — AbacusAI documentation

# `abacusai.refresh_pipeline_run`

## Module Contents

### Classes

`RefreshPipelineRun` | A refresh policy run or a project refresh run.

class abacusai.refresh_pipeline_run.RefreshPipelineRun(client, refreshPipelineRunId=None, refreshPolicyId=None, createdAt=None, startedAt=None, completedAt=None, status=None, refreshType=None, datasetVersions=None, modelVersions=None, predictionMetricVersions=None, deploymentVersions=None, batchPredictions=None, refreshPolicy={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A refresh policy run or a project refresh run.

  Parameters

    - client (ApiClient) – An authenticated API Client instance

    - refreshPipelineRunId (str) – The unique identifier for the refresh pipeline run

    - refreshPolicyId (str) – Populated when the run was triggered by a refresh policy

    - createdAt (str) – The time when this refresh pipeline run was created

    - startedAt (str) – The time when the refresh pipeline run was started

    - completedAt (is-8601 string) – The time when the refresh pipeline run was completed

    - status (str) – The status of the refresh pipeline run

    - refreshType (str) – The type of refresh policy to be run

    - datasetVersions (list of string identifiers) – Comma separated list of Dataset version IDs that this refresh pipeline run is monitoring

    - modelVersions (list of string identifiers) – Comma separated list of Model version IDs that this refresh pipeline run is monitoring

    - predictionMetricVersions (list) –

    - deploymentVersions (list of string identifiers) – Comma separated list of Deployment version IDs that this refresh pipeline run is monitoring

    - batchPredictions (list of string identifiers) – Comma separated list of batch predictionn IDs that this refresh pipeline run is monitoring

    - refreshPolicy (RefreshPolicy) –

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns

      The dict value representation of the class parameters

    Return type

      dict

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns

      The current object

    Return type

      RefreshPipelineRun

  describe()

    Retrieve a single refresh pipeline run

    Parameters

      refresh_pipeline_run_id (str) – The unique ID associated with this refresh pipeline_run

    Returns

      A refresh pipeline run object

    Return type

      RefreshPipelineRun